@@ -1,11 +1,11 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: cpphs
-version: 1.19.3
-id: cpphs-1.19.3-8cb6c3761dbbd3c20e10f28974c8d246
-key: cpphs_BDvNj43Ytlf6FLaXjoKVEk
+version: 1.20.1
+id: cpphs-1.20.1-46b13f1ef390a545ec653266d5170426
+key: cpphs_GFZcQ7jDfUx2dsujmc7HXk
 license: LGPL
-copyright: 2004-2015, Malcolm Wallace
+copyright: 2004-2016, Malcolm Wallace
 maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
 homepage: http://projects.haskell.org/cpphs/
 synopsis: A liberalised re-implementation of cpp, the C pre-processor.
@@ -34,10 +34,10 @@ hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                 Language.Preprocessor.Cpphs.SymTab
                 Language.Preprocessor.Cpphs.Tokenise
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.19.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.19.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/cpphs-1.19.3
-hs-libraries: HScpphs-1.19.3-BDvNj43Ytlf6FLaXjoKVEk
+import-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/cpphs-1.20.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/cpphs-1.20.1
+hs-libraries: HScpphs-1.20.1-GFZcQ7jDfUx2dsujmc7HXk
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
